# Model Context Protocol documentation

**This documentation has moved to [modelcontextprotocol/modelcontextprotocol](https://github.com/modelcontextprotocol/modelcontextprotocol/tree/main/docs).**

Please file issues and pull requests for documentation changes there.
